@@ -3,18 +3,30 @@
 """Main module."""
 
 
-import os
-import requests
 import json
 import logging
-import socket
+import os
+import sys
+
+import requests
 
 logging.basicConfig(level=logging.INFO, format="%(levelname)s:%(message)s")
 URL = "https://api.alwaysdata.com/v1/{what}/"
 # get API credentials environment variables
-apikey = os.getenv("AD_APIKEY")
-account = os.getenv("AD_ACCOUNT")
-CREDENTIALS = (f"{apikey} account={account}", "")
+APIKEY = os.getenv("AD_APIKEY")
+ACCOUNT = os.getenv("AD_ACCOUNT")
+
+
+def check_envars():
+    if not APIKEY:
+        logging.critical("env variable `AD_APIKEY` is not defined")
+        sys.exit(1)
+    if not APIKEY:
+        logging.critical("env variable `AD_ACCOUNT` is not defined")
+        sys.exit(1)
+
+
+CREDENTIALS = (f"{APIKEY} account={ACCOUNT}", "")
 
 
 def check_if_single(seq):
@@ -38,7 +50,6 @@ def getIP(url=None, type="A"):
     '...'
     """
     if url:
-        # ip = socket.gethostbyname(url)
         ip = get_site_record(url, type=type)["value"]
     else:
         # get own public IP
@@ -123,6 +134,7 @@ def get_site_record(url, check_single=True, type="A"):
 
 
 def modify_record_targetIP(url=None, targetIP=None, dry_run=False):
+    check_envars()
     if not url:
         url = os.getenv("AD_SITE_URL")
     logging.info(f"checking {url=}")
@@ -160,6 +172,7 @@ def modify_record_targetIP(url=None, targetIP=None, dry_run=False):
 
 
 def modify_record_cname(url=None, cname_target=None, dry_run=False):
+    check_envars()
     if not url:
         url = os.getenv("AD_SITE_CNAME")
     logging.info(f"checking {url=}")
