@@ -4,7 +4,7 @@
 import argparse
 import sys
 
-from adbasicapi.api import modify_record_targetIP, modify_record_cname
+from adbasicapi.api import modify_record_cname, modify_record_targetIP
 
 
 def changeIP():
